@@ -53,13 +53,13 @@ from matplotlib.widgets import Cursor
 from matplotlib.pyplot import subplot2grid#, silent_list
 
 from wavepy2.util.plot import plot_tools
-from wavepy2.util.plot.plotter import WavePyWidget, WavePyInteractiveWidget
+from wavepy2.util.plot.plotter import WavePyWidget, WavePyInteractiveWidget, pixels_to_inches
 
 from warnings import filterwarnings
 filterwarnings("ignore")
 
 class PlotProfile(WavePyWidget):
-    def allows_saving(self): return False
+    def _allows_saving(self): return False
 
     def get_plot_tab_name(self):
         return self.__title
@@ -96,6 +96,11 @@ class PlotProfile(WavePyWidget):
         try:    arg4side = kwargs["arg4side"]
         except: arg4side = {}
 
+        try:    figure_width = kwargs["figure_width"]*pixels_to_inches
+        except: figure_width = 10
+        try:    figure_height = kwargs["figure_height"]*pixels_to_inches
+        except: figure_height = 7.5
+
         layout = QHBoxLayout()
         layout.setAlignment(Qt.AlignCenter)
 
@@ -116,7 +121,9 @@ class PlotProfile(WavePyWidget):
                                                 do_fwhm=do_fwhm,
                                                 arg4main=arg4main,
                                                 arg4top=arg4top,
-                                                arg4side=arg4side)
+                                                arg4side=arg4side,
+                                                figure_width=figure_width,
+                                                figure_height=figure_height)
 
         self.setFixedWidth(plot_profile_widget.width())
         self.setFixedHeight(plot_profile_widget.height())
@@ -160,6 +167,11 @@ class PlotProfileInteractive(WavePyInteractiveWidget):
         try: arg4side = kwargs["arg4side"]
         except: arg4side = {}
 
+        try:    figure_width = kwargs["figure_width"]*pixels_to_inches
+        except: figure_width = 10
+        try:    figure_height = kwargs["figure_height"]*pixels_to_inches
+        except: figure_height = 7.5
+
         layout = QHBoxLayout()
         layout.setAlignment(Qt.AlignCenter)
 
@@ -180,7 +192,9 @@ class PlotProfileInteractive(WavePyInteractiveWidget):
                                                        do_fwhm=do_fwhm,
                                                        arg4main=arg4main,
                                                        arg4top=arg4top,
-                                                       arg4side=arg4side)
+                                                       arg4side=arg4side,
+                                                       figure_width=figure_width,
+                                                       figure_height=figure_height)
 
         self.setFixedWidth(self.__plot_profile_widget.width())
         self.setFixedHeight(self.__plot_profile_widget.height())
@@ -259,12 +273,12 @@ class PlotProfileWidget(QWidget):
     def __init__(self, parent, xmatrix, ymatrix, zmatrix,
                  xlabel='x', ylabel='y', zlabel='z', title='Title',
                  xo=None, yo=None, xunit='', yunit='', do_fwhm=True,
-                 arg4main={'cmap': 'viridis'}, arg4top={}, arg4side={}):
+                 arg4main={'cmap': 'viridis'}, arg4top={}, arg4side={}, figure_width=11, figure_height=8.5):
         super(PlotProfileWidget, self).__init__(parent)
 
         layout = QHBoxLayout()
 
-        figure_canvas = FigureCanvas(Figure(facecolor="white", figsize=(11., 8.5)))
+        figure_canvas = FigureCanvas(Figure(facecolor="white", figsize=(figure_width, figure_height)))
         fig = figure_canvas.figure
 
         z_min, z_max = float(np.nanmin(zmatrix)), float(np.nanmax(zmatrix))
@@ -394,7 +408,7 @@ class PlotProfileWidget(QWidget):
             side_subplot.set_ylim(main_subplot_y_min, main_subplot_y_max)
 
             fig.texts = []
-            fig.text(.8, .75, message, fontsize=14, va='bottom', bbox=dict(facecolor=last_color, alpha=0.5))
+            fig.text(.76, .75, message, fontsize=14, va='bottom', bbox=dict(facecolor=last_color, alpha=0.5))
             fig.canvas.draw_idle()
 
             return [_delta_x, _delta_y]
