@@ -482,7 +482,7 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
         self.__script_logger.print('Initial Vt Mean angle/pi : {:} pi'.format(np.mean(angle[1]/np.pi)))
 
         self.__plotter.push_plot_on_context(CORRECT_ZERO_DPC_CONTEXT_KEY, CorrectDPC, unique_id,
-                                            angle=angle, pi_jump=pi_jump, **kwargs)
+                                            angle=angle, pi_jump=pi_jump, ignores_figure_dimensions=True, **kwargs)
 
         def __get_dpc(angle_i, pixelsize_i):
             return angle_i * pixelsize_i / factor
@@ -513,18 +513,18 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
             differential_phase_10 = __get_dpc(angle[1], pixelsize[1])
 
             self.__plotter.push_plot_on_context(CORRECT_ZERO_DPC_CONTEXT_KEY, CorrectDPCHistos, unique_id,
-                                                angle=angle, title="Remove mean", **kwargs)
+                                                angle=angle, title="Remove mean", ignores_figure_dimensions=True, **kwargs)
             self.__plotter.push_plot_on_context(CORRECT_ZERO_DPC_CONTEXT_KEY, PlotDPC, unique_id,
                                                 differential_phase_01=differential_phase_01, differential_phase_10=differential_phase_10, pixelsize=virtual_pixelsize, titleStr="Remove Mean", **kwargs)
 
         if correct_dpc_center and self.__plotter.is_active():
-            angle = self.__plotter.show_interactive_plot(CorrectDPCCenter, container_widget=None, angle=angle)
+            angle = self.__plotter.show_interactive_plot(CorrectDPCCenter, container_widget=None, angle=angle, ignores_figure_dimensions=True, **kwargs)
 
             differential_phase_01 = __get_dpc(angle[0], pixelsize[0])
             differential_phase_10 = __get_dpc(angle[1], pixelsize[1])
 
             self.__plotter.push_plot_on_context(CORRECT_ZERO_DPC_CONTEXT_KEY, CorrectDPCHistos, unique_id,
-                                                angle=angle, title="Correct DPC Center", **kwargs)
+                                                angle=angle, title="Correct DPC Center", ignores_figure_dimensions=True, **kwargs)
             self.__plotter.push_plot_on_context(CORRECT_ZERO_DPC_CONTEXT_KEY, PlotDPC, unique_id,
                                                 differential_phase_01=differential_phase_01, differential_phase_10=differential_phase_10, pixelsize=virtual_pixelsize, titleStr="Correct DPC Center", **kwargs)
 
@@ -696,7 +696,6 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
     def crop_for_integration(self, dpc_result, initialization_parameters, plotting_properties=PlottingProperties(), **kwargs):
         differential_phase_01 = dpc_result.get_parameter("differential_phase_01")
         differential_phase_10 = dpc_result.get_parameter("differential_phase_10")
-        virtual_pixelsize     = dpc_result.get_parameter("virtual_pixelsize")
 
         do_integration   = initialization_parameters.get_parameter("do_integration")
 
@@ -704,7 +703,6 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
             differential_phase_01, differential_phase_10 = self.__crop_for_integration(plotting_properties,
                                                                                        differential_phase_01=differential_phase_01,
                                                                                        differential_phase_10=differential_phase_10,
-                                                                                       pixelsize=virtual_pixelsize,
                                                                                        message="Crop Differential Phase for Integration", **kwargs)
             dpc_result.set_parameter("differential_phase_01", differential_phase_01)
             dpc_result.set_parameter("differential_phase_10", differential_phase_10)
@@ -859,7 +857,6 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
     def crop_2nd_order_component_of_the_phase_1(self, integration_result, initialization_parameters, plotting_properties=PlottingProperties(), **kwargs):
         differential_phase_01   = integration_result.get_parameter("differential_phase_01")
         differential_phase_10   = integration_result.get_parameter("differential_phase_10")
-        virtual_pixelsize       = integration_result.get_parameter("virtual_pixelsize")
         linear_fit_dpc_01       = integration_result.get_parameter("linear_fit_dpc_01")
         linear_fit_dpc_10       = integration_result.get_parameter("linear_fit_dpc_10")
 
@@ -872,7 +869,6 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
             differential_phase_01_crop_1, differential_phase_10_crop_1 = self.__crop_for_integration(plotting_properties,
                                                                                                      differential_phase_01=linear_fit_dpc_01,
                                                                                                      differential_phase_10=linear_fit_dpc_10,
-                                                                                                     pixelsize=virtual_pixelsize,
                                                                                                      message="New Crop for 2nd order component of the phase?", **kwargs)
         else:
             differential_phase_01_crop_1 = differential_phase_01
@@ -974,7 +970,6 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
         differential_phase_01        = integration_result.get_parameter("differential_phase_01")
         differential_phase_10        = integration_result.get_parameter("differential_phase_10")
 
-        virtual_pixelsize       = integration_result.get_parameter("virtual_pixelsize")
         linear_fit_dpc_01       = integration_result.get_parameter("linear_fit_dpc_01")
         linear_fit_dpc_10       = integration_result.get_parameter("linear_fit_dpc_10")
 
@@ -987,7 +982,6 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
             differential_phase_01_crop_2, differential_phase_10_crop_2 = self.__crop_for_integration(plotting_properties,
                                                                                                      differential_phase_01=differential_phase_01 - linear_fit_dpc_01,
                                                                                                      differential_phase_10=differential_phase_10 - linear_fit_dpc_10,
-                                                                                                     pixelsize=virtual_pixelsize,
                                                                                                      message="New Crop for 2nd order component of the phase?", **kwargs)
         else:
             differential_phase_01_crop_2 = differential_phase_01
@@ -1124,7 +1118,7 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
     # PRIVATE METHODS
 
     @classmethod
-    def __draw_crop_for_integration(cls, plotting_properties, differential_phase_01, differential_phase_10, pixelsize, message="New Crop for Integration?", **kwargs):
+    def __draw_crop_for_integration(cls, plotting_properties, differential_phase_01, differential_phase_10, message="New Crop for Integration?", **kwargs):
         img_to_crop = differential_phase_01 ** 2 + differential_phase_10 ** 2
 
         vmin = grating_interferometry.mean_plus_n_sigma(img_to_crop, -3)
@@ -1132,30 +1126,24 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
 
         return crop_image.draw_crop_image(img=img_to_crop,
                                           message=message,
-                                          pixelsize=pixelsize,
-                                          kargs4graph={'cmap': 'viridis', 'vmin': vmin, 'vmax': vmax},
+                                          kwargs4graph={'cmap': 'viridis', 'vmin': vmin, 'vmax': vmax},
                                           plotting_properties=plotting_properties,
                                           application_name=APPLICATION_NAME,
                                           **kwargs)
 
     @classmethod
-    def __crop_for_integration(cls, plotting_properties, differential_phase_01, differential_phase_10, pixelsize, calc_minmax=True, message="New Crop for Integration?", **kwargs):
+    def __crop_for_integration(cls, plotting_properties, differential_phase_01, differential_phase_10, message="New Crop for Integration?", **kwargs):
         image_to_crop = differential_phase_01 ** 2 + differential_phase_10 ** 2
 
-        if calc_minmax:
-            vmin = grating_interferometry.mean_plus_n_sigma(image_to_crop, -3)
-            vmax = grating_interferometry.mean_plus_n_sigma(image_to_crop, 3)
-            kargs4graph = {'cmap': 'viridis', 'vmin': vmin, 'vmax': vmax}
-        else:
-            kargs4graph = {}
-
         plotter = get_registered_plotter_instance(application_name=APPLICATION_NAME)
 
         if plotter.is_active():
+            vmin = grating_interferometry.mean_plus_n_sigma(image_to_crop, -3)
+            vmax = grating_interferometry.mean_plus_n_sigma(image_to_crop, 3)
+
             _, idx4crop, _ = crop_image.crop_image(img=image_to_crop,
                                                    message=message,
-                                                   pixelsize=pixelsize,
-                                                   kargs4graph=kargs4graph,
+                                                   kwargs4graph={'cmap': 'viridis', 'vmin': vmin, 'vmax': vmax},
                                                    plotting_properties=plotting_properties,
                                                    application_name=APPLICATION_NAME,
                                                    **kwargs)
@@ -1180,8 +1168,7 @@ class __SingleGratingTalbot(SingleGratingTalbotFacade):
         grad_x, grad_y, error_x, error_y = surface_from_grad.error_integration(delx_f=delx_f,
                                                                                dely_f=dely_f,
                                                                                func=phase,
-                                                                               shifthalfpixel=False,
-                                                                               **kwargs)
+                                                                               shifthalfpixel=False)
 
         self.__plotter.push_plot_on_context(context_key, ErrorIntegration, unique_id,
                                             delx_f=delx_f, dely_f=dely_f, func=phase, grad_x=grad_x, grad_y=grad_y, error_x=error_x, error_y=error_y, pixelsize=pixelsize, **kwargs)
