@@ -59,12 +59,23 @@ def set_screen_at_center(window):
     window.move(qtRectangle.topLeft())
     window.update()
 
-class DefaultMainWindow(QMainWindow):
+class AbstractContextWidget():
+
+    def __init__(self, container_widget):
+        self.__container_widget = container_widget
+
+    def get_container_widget(self):
+        return self.__container_widget
+
+class DefaultContextWidget(AbstractContextWidget):
+    def __init__(self, container_widget):
+        super(DefaultContextWidget, self).__init__(container_widget)
+
+class DefaultMainWindow(QMainWindow, AbstractContextWidget):
     def __init__(self, title):
-        super().__init__()
+        super(DefaultMainWindow, self).__init__(container_widget=QWidget())
         self.setWindowTitle(title)
-        self.__container_widget = QWidget()
-        self.setCentralWidget(self.__container_widget)
+        self.setCentralWidget(self.get_container_widget())
 
         desktop_widget = QDesktopWidget()
         actual_geometry = self.frameGeometry()
@@ -77,9 +88,33 @@ class DefaultMainWindow(QMainWindow):
 
         self.setGeometry(new_geometry)
 
+        self.setStyleSheet(stylesheet_string)
+
+class PlottingProperties:
+    def __init__(self, container_widget=None, context_widget=None, **parameters):
+        self.__container_widget = container_widget
+        self.__context_widget = context_widget
+        self.__parameters = parameters
+
     def get_container_widget(self):
         return self.__container_widget
 
+    def get_context_widget(self):
+        return self.__context_widget
+
+    def get_parameters(self):
+        return self.__parameters
+
+    def get_parameter(self, parameter_name, default_value=None):
+        try:
+            return self.__parameters[parameter_name]
+        except:
+            return default_value
+
+    def set_parameter(self, parameter_name, value):
+        self.__parameters[parameter_name] = value
+
+
 WIDGET_FIXED_WIDTH = 800
 
 ##########################################################################
@@ -88,43 +123,8 @@ WIDGET_FIXED_WIDTH = 800
 from wavepy2.util.log.logger import get_registered_logger_instance
 from wavepy2.util.common import common_tools
 
-def save_sdf_file(array, pixelsize=[1, 1], fname='output.sdf', extraHeader={}):
-    '''
-    Save an 2D array in the `Surface Data File Format (SDF)
-    <https://physics.nist.gov/VSC/jsp/DataFormat.jsp#a>`_ , which can be
-    viewed
-    with the program `Gwyddion
-    <http://gwyddion.net/documentation/user-guide-en/>`_ .
-    It is also useful because it is a plain
-    ASCII file
-
-
-    Parameters
-    ----------
-    array: 2D ndarray
-        data to be saved as *sdf*
-
-    pixelsize: list
-        list in the format [pixel_size_i, pixel_size_j]
-
-    fname: str
-        output file name
-
-    extraHeader: dict
-        dictionary with extra fields to be added to the header. Note that this
-        extra header have not effect when using Gwyddion. It is used only for
-        the asc file and when loaded by :py:func:`wavepy.utils.load_sdf`
-        as *headerdic*.
-
-
-    See Also
-    --------
-    :py:func:`wavepy.utils.load_sdf`
-
-
-    '''
-
-    logger = get_registered_logger_instance()
+def save_sdf_file(array, pixelsize=[1, 1], fname='output.sdf', extraHeader={}, application_name=None):
+    logger = get_registered_logger_instance(application_name=application_name)
 
     if len(array.shape) != 2:
         logger.print_error('Function save_sdf: array must be 2-dimensional')
@@ -160,31 +160,8 @@ def save_sdf_file(array, pixelsize=[1, 1], fname='output.sdf', extraHeader={}):
     logger.print_message(fname + ' saved!')
 
 
-def save_csv_file(arrayList, fname='output.csv', headerList=[], comments=''):
-    '''
-    Save an 2D array as a *comma separeted values* file. This is appropriated
-    to save several 1D curves. For 2D data use :py:func:`wavepy.utils.save_sdf`
-
-
-    Parameters
-    ----------
-    array: 2D ndarray
-        data to be saved as *sdf*
-
-    fname: str
-        output file name
-
-    headerList: dict
-        dictionary with fields to be added to the header.
-
-
-    See Also
-    --------
-    :py:func:`wavepy.utils.load_csv_file`
-
-    '''
-
-    logger = get_registered_logger_instance()
+def save_csv_file(arrayList, fname='output.csv', headerList=[], comments='', application_name=None):
+    logger = get_registered_logger_instance(application_name=application_name)
 
     header = ''
     if headerList != []:
@@ -208,27 +185,57 @@ def save_csv_file(arrayList, fname='output.csv', headerList=[], comments=''):
     np.savetxt(fname, data2save, fmt=fmt, header=header, delimiter=', ')
     logger.print_message(fname + ' saved!')
 
+
+def load_sdf_file(fname, printHeader=False):
+    with open(fname) as input_file:
+        nline = 0
+        header = ''
+        if printHeader: print('########## HEADER from ' + fname)
+
+        for line in input_file:
+            nline += 1
+            if printHeader: print(line, end='')
+            if 'NumPoints' in line: xpoints = int(line.split('=')[-1])
+            if 'NumProfiles' in line: ypoints = int(line.split('=')[-1])
+            if 'Xscale' in line: xscale = float(line.split('=')[-1])
+            if 'Yscale' in line: yscale = float(line.split('=')[-1])
+            if 'Zscale' in line: zscale = float(line.split('=')[-1])
+            if '*' in line: break
+            else: header += line
+
+    if printHeader: print('########## END HEADER from ' + fname)
+
+    data = np.loadtxt(fname, skiprows=nline)
+    data = data.reshape(ypoints, xpoints)*zscale
+    headerdic = {}
+    header = header.replace('\t', '')
+    for item in header.split('\n'):
+        items = item.split('=')
+        if len(items) > 1: headerdic[items[0]] = items[1]
+
+    return data, [yscale, xscale], headerdic
+
+def load_csv_file(fname):
+    with open(fname) as input_file:
+        comments = []
+        for line in input_file:
+            if '#' in line:
+                comments.append(line[2:-1])
+                header = line[2:-1]  # remove # and \n
+            else: break
+
+    data = np.loadtxt(fname, delimiter=',')
+
+    headerlist = []
+    for item in header.split(', '): headerlist.append(item)
+
+    return data, headerlist, comments
+
+
 from matplotlib.pyplot import get_cmap
 import itertools
 
 def line_style_cycle(ls=['-', '--'], ms=['s', 'o', '^', 'd'], ncurves=2, cmap_str='default'):
-    '''
-    Generate a list with cycle of linestyles for plots. See
-    `here <http://matplotlib.org/api/pyplot_api.html?highlight=plot#matplotlib.pyplot.plot>`_
-    for imformation about the syntax of the styles.
-
-    Example
-    -------
-
-    >>> ls_cycle, lc_cycle = line_style_cycle(ncurves=10)
-    >>> x = np.linspace(0, 100, 10)
-    >>> for i in range (10):
-    >>>     plt.plot(x, i*x, next(ls_cycle), color=next(lc_cycle), label=str(i))
-    >>> plt.legend()
-    >>> plt.show()
-
-    '''
-
     list_ls = list(a[0] + a[1] for a in itertools.product(ls, ms))
     ls_cycle = itertools.cycle(list_ls[0:ncurves])
 
@@ -248,23 +255,6 @@ def line_style_cycle(ls=['-', '--'], ms=['s', 'o', '^', 'd'], ncurves=2, cmap_st
 from scipy.interpolate import UnivariateSpline
 
 def fwhm_xy(xvalues, yvalues):
-    """
-    Calculate FWHM of a vector  y(x)
-
-    Parameters
-    ----------
-    xvalues : ndarray
-        vector with the values of x
-    yvalues : ndarray
-        vector with the values of x
-
-    Returns
-    -------
-    list
-        list of values x and y(x) at half maximum in the format
-        [[fwhm_x1, fwhm_x2], [fwhm_y1, fwhm_y2]]
-    """
-
     spline = UnivariateSpline(xvalues, yvalues-np.min(yvalues)/2-np.max(yvalues)/2, s=0)
 
     xvalues = spline.roots().tolist()
@@ -957,3 +947,429 @@ def __connectControl(master, value, f, signal, cfront, cback=None, cfunc=None, f
         cfront.opposite = tuple(filter(None, (cback, cfunc)))
 
     return cfront, cback, cfunc
+
+stylesheet_string = "" + \
+"/*" + "\n" + \
+" * Icon search paths relative to this files directory." + "\n" + \
+" * (main.py script will add this to QDir.searchPaths)" + "\n" + \
+" */" + "\n" + \
+"" + "\n" + \
+"/* Main window background color */" + "\n" + \
+"" + "\n" + \
+"QMainWindow {" + "\n" + \
+"    background-color: #E9EFF2;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"QMainWindow::separator {" + "\n" + \
+"    width: 1px; /* when vertical */" + "\n" + \
+"    height: 1px; /* when horizontal */" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"/* The widget buttons in the dock tool box */" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox WidgetToolGrid QToolButton {" + "\n" + \
+"    border: none;" + "\n" + \
+"    background-color: #F2F2F2;" + "\n" + \
+"    border-radius: 8px;" + "\n" + \
+"/*" + "\n" + \
+"    font-family: \"Helvetica\";" + "\n" + \
+"    font-size: 10px;" + "\n" + \
+"    font-weight: bold;" + "\n" + \
+"*/" + "\n" + \
+"    color: #333;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"/* Dock widget tool box tab buttons (categories) */" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox QToolButton#toolbox-tab-button {" + "\n" + \
+"    /* nativeStyling property overrides the QStyle and uses a fixed drawing" + "\n" + \
+"    routine */" + "\n" + \
+"    qproperty-nativeStyling_: \"false\";" + "\n" + \
+"" + "\n" + \
+"    font-family: \"Helvetica\";" + "\n" + \
+"    font-size: 14px;" + "\n" + \
+"    font-weight: bold;" + "\n" + \
+"    color: #333;" + "\n" + \
+"    border: none;" + "\n" + \
+"    border-bottom: 1px solid #B5B8B8;" + "\n" + \
+"    background: qlineargradient(" + "\n" + \
+"        x1: 0, y1: 0, x2: 0, y2: 1," + "\n" + \
+"        stop: 0 #F2F2F2," + "\n" + \
+"        stop: 0.5 #F2F2F2," + "\n" + \
+"        stop: 0.8 #EBEBEB," + "\n" + \
+"        stop: 1.0 #DBDBDB" + "\n" + \
+"    );" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox QToolButton#toolbox-tab-button:hover {" + "\n" + \
+"    background-color: palette(light);" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox QToolButton#toolbox-tab-button:checked {" + "\n" + \
+"    background-color: palette(dark);" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox QToolButton#toolbox-tab-button:focus {" + "\n" + \
+"    background-color: palette(highlight);" + "\n" + \
+"    border: 1px solid #609ED7" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox ToolGrid {" + "\n" + \
+"    background-color: #F2F2F2;" + "\n" + \
+"    padding-bottom: 8px;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox QWidget#toolbox-contents {" + "\n" + \
+"    background-color: #F2F2F2; /* match the ToolGrid's background */" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox ToolGrid QToolButton[last-column] {" + "\n" + \
+"    border-right: none;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox  ToolGrid QToolButton:focus {" + "\n" + \
+"    background-color: palette(window);" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox  ToolGrid QToolButton:hover {" + "\n" + \
+"    background-color: palette(light);" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"WidgetToolBox  ToolGrid QToolButton:pressed {" + "\n" + \
+"    background-color: palette(dark);" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"/* QuickCategoryToolbar popup menus */" + "\n" + \
+"" + "\n" + \
+"CategoryPopupMenu {" + "\n" + \
+"	background-color: #E9EFF2;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"CategoryPopupMenu ToolTree QTreeView::item {" + "\n" + \
+"	height: 25px;" + "\n" + \
+"	border-bottom: 1px solid #e9eff2;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"CategoryPopupMenu QTreeView::item:selected {" + "\n" + \
+"	background: qlineargradient(" + "\n" + \
+"		x1: 0, y1: 0, x2: 0, y2: 1," + "\n" + \
+"		stop: 0 #688EF6," + "\n" + \
+"		stop: 0.5 #4047f4," + "\n" + \
+"		stop: 1.0 #2D68F3" + "\n" + \
+"	);" + "\n" + \
+"	color: white;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"/* Canvas Dock Header */" + "\n" + \
+"" + "\n" + \
+"CollapsibleDockWidget::title {" + "\n" + \
+"    background: qlineargradient(" + "\n" + \
+"        x1: 0, y1: 0, x2: 0, y2: 1," + "\n" + \
+"        stop: 0 #808080, stop: 1.0 #666" + "\n" + \
+"    );" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"/* Dock widget title bar button icons (icon size for both must be set)." + "\n" + \
+" * The buttons define the title bar height." + "\n" + \
+" */" + "\n" + \
+"" + "\n" + \
+"CollapsibleDockWidget::close-button, CollapsibleDockWidget::float-button {" + "\n" + \
+"    padding: 1px;" + "\n" + \
+"    icon-size: 11px;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"CanvasToolDock WidgetToolBox {" + "\n" + \
+"    border: 1px solid #B5B8B8;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"/* Toolbar at the bottom of the dock widget when in in expanded state" + "\n" + \
+" */" + "\n" + \
+"" + "\n" + \
+"CanvasToolDock QToolBar {" + "\n" + \
+"    height: 28;" + "\n" + \
+"    spacing: 1;" + "\n" + \
+"    border: none;" + "\n" + \
+"    /*" + "\n" + \
+"    background: qlineargradient(" + "\n" + \
+"        x1: 0, y1: 0, x2: 0, y2: 1," + "\n" + \
+"        stop: 0 #808080, stop: 1.0 #666" + "\n" + \
+"    );" + "\n" + \
+"    */" + "\n" + \
+"    background-color: #898989;" + "\n" + \
+"" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"CanvasToolDock QToolBar QToolButton {" + "\n" + \
+"    border: none;" + "\n" + \
+"    background: qlineargradient(" + "\n" + \
+"        x1: 0, y1: 0, x2: 0, y2: 1," + "\n" + \
+"        stop: 0 #808080, stop: 1.0 #666" + "\n" + \
+"    );" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"CanvasToolDock QToolBar QToolButton:menu-indicator {" + "\n" + \
+"     image: url(canvas_icons:/Dropdown.svg);" + "\n" + \
+"     subcontrol-position: top right;" + "\n" + \
+"     height: 8px;" + "\n" + \
+"     width: 8px;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"CanvasToolDock QToolBar QToolButton:checked," + "\n" + \
+"CanvasToolDock QToolBar QToolButton:pressed {" + "\n" + \
+"    background-color: #FFA840;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"/* Toolbar in the dock when in collapsed state." + "\n" + \
+" */" + "\n" + \
+"" + "\n" + \
+"CollapsibleDockWidget QWidget#canvas-quick-dock QToolBar {" + "\n" + \
+"    spacing: 1;" + "\n" + \
+"    border: none;" + "\n" + \
+"    /*" + "\n" + \
+"    background: qlineargradient(" + "\n" + \
+"        x1: 0, y1: 0, x2: 0, y2: 1," + "\n" + \
+"        stop: 0 #808080, stop: 1.0 #666" + "\n" + \
+"    );" + "\n" + \
+"    */" + "\n" + \
+"    background-color: #898989;" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"" + "\n" + \
+"CollapsibleDockWidget QWidget#canvas-quick-dock QToolBar QToolButton {" + "\n" + \
+"    border: none;" + "\n" + \
+"    background: qlineargradient(" + "\n" + \
+"        x1: 0, y1: 0, x2: 1, y2: 0," + "\n" + \
+"        stop: 0 #808080, stop: 1.0 #666" + "\n" + \
+"    );" + "\n" + \
+"}" + "\n" + \
+"" + "\n" + \
+"CollapsibleDockWidget QWidget#canvas-quick-dock QToolBar QToolButton:menu-indicator {"+ "\n" + \
+"     image: url(canvas_icons:/Dropdown.svg);"+ "\n" + \
+"     subcontrol-position: top right;"+ "\n" + \
+"     height: 8px;"+ "\n" + \
+"     width: 8px;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"CollapsibleDockWidget QWidget#canvas-quick-dock QToolBar QToolButton:checked,"+ "\n" + \
+"CollapsibleDockWidget QWidget#canvas-quick-dock QToolBar QToolButton:pressed {"+ "\n" + \
+"    background-color: #FFA840;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+""+ "\n" + \
+"/* Splitter between the widget toolbox and quick help."+ "\n" + \
+" */"+ "\n" + \
+""+ "\n" + \
+"CanvasToolDock QSplitter::handle {"+ "\n" + \
+"    border: 1px solid #B5B8B8;"+ "\n" + \
+""+ "\n" + \
+"/*    border-top: 1px solid #B5B8B8;"+ "\n" + \
+" *   border-bottom: 1px solid #B5B8B8;"+ "\n" + \
+" *   border-left: 1px solid #B6B6B6;"+ "\n" + \
+" *   border-right: 1px solid #B6B6B6;"+ "\n" + \
+" */"+ "\n" + \
+""+ "\n" + \
+"    background:  qlineargradient("+ "\n" + \
+"        x1: 0, y1: 0, x2: 0, y2: 1,"+ "\n" + \
+"        stop: 0 #D4D4D4, stop: 0.05 #EDEDED,"+ "\n" + \
+"        stop: 0.5 #F2F2F2,"+ "\n" + \
+"        stop: 0.95 #EDEDED, stop: 1.0 #E0E0E0"+ "\n" + \
+"    );"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+""+ "\n" + \
+"/* Scheme Info Dialog"+ "\n" + \
+" */"+ "\n" + \
+""+ "\n" + \
+"SchemeInfoDialog {"+ "\n" + \
+"    font-family: \"Helvetica\";"+ "\n" + \
+"    background-color: #E9EFF2;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"SchemeInfoDialog SchemeInfoEdit QLabel {"+ "\n" + \
+"    font-family: \"Helvetica\";"+ "\n" + \
+"    font-weight: bold;"+ "\n" + \
+"    font-size: 16px;"+ "\n" + \
+"    color: black;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"SchemeInfoDialog QLabel#heading {"+ "\n" + \
+"    font-size: 21px;"+ "\n" + \
+"    color: #515151;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"SchemeInfoDialog StyledWidget#auto-show-container * {"+ "\n" + \
+"    font-family: \"Helvetica\";"+ "\n" + \
+"    font-size: 12px;"+ "\n" + \
+"    color: #1A1A1A;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"SchemeInfoDialog StyledWidget#auto-show-container {"+ "\n" + \
+"    border-top: 1px solid #C1C2C3;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"SchemeInfoDialog SchemeInfoEdit QLineEdit {"+ "\n" + \
+"    padding: 4px;"+ "\n" + \
+"    /* background-color: red; */"+ "\n" + \
+"    /* font-weight: normal; */"+ "\n" + \
+"    font-size: 12px;"+ "\n" + \
+"    color: #1A1A1A;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"SchemeInfoDialog SchemeInfoEdit QTextEdit {"+ "\n" + \
+"    padding: 4px;"+ "\n" + \
+"    background-color: white;"+ "\n" + \
+"    /* font-weight: normal; */"+ "\n" + \
+"    font-size: 12px;"+ "\n" + \
+"    color: #1A1A1A;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+""+ "\n" + \
+"/* Preview Dialog (Recent Schemes and Tutorials)"+ "\n" + \
+" */"+ "\n" + \
+""+ "\n" + \
+"PreviewDialog {"+ "\n" + \
+"    background-color: #E9EFF2;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"PreviewDialog QLabel#heading {"+ "\n" + \
+"    font-family: \"Helvetica\";"+ "\n" + \
+"    font-weight: bold;"+ "\n" + \
+"    font-size: 21px;"+ "\n" + \
+"    color: #515151;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"PreviewDialog PreviewBrowser * {"+ "\n" + \
+"    font-family: \"Helvetica\";"+ "\n" + \
+"    color: #1A1A1A;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"PreviewDialog PreviewBrowser TextLabel#path-text {"+ "\n" + \
+"    font-size: 12px;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"PreviewDialog PreviewBrowser QLabel#path-label {"+ "\n" + \
+"    font-size: 12px;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"PreviewDialog DropShadowFrame {"+ "\n" + \
+"    qproperty-radius_: 10;"+ "\n" + \
+"    qproperty-color_: rgb(0, 0, 0, 100);"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"/* Welcome Screen Dialog"+ "\n" + \
+" */"+ "\n" + \
+""+ "\n" + \
+"WelcomeDialog {"+ "\n" + \
+"    background-color: #E9EFF2;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"WelcomeDialog QToolButton {"+ "\n" + \
+"	font-family: \"Helvetica\";"+ "\n" + \
+"	font-size: 13px;"+ "\n" + \
+"	font-style: normal;"+ "\n" + \
+"	font-weight: bold;"+ "\n" + \
+"	color: #333;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"WelcomeDialog QWidget#bottom-bar {"+ "\n" + \
+"	border-top: 1px solid #C1C2C3;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"WelcomeDialog QWidget#bottom-bar QCheckBox {	"+ "\n" + \
+"	font-family: \"Helvetica\";"+ "\n" + \
+"	font-size: 12px;"+ "\n" + \
+"	color: #333;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"/* SchemeEditWidget"+ "\n" + \
+" */"+ "\n" + \
+""+ "\n" + \
+"SchemeEditWidget {"+ "\n" + \
+"	font-family: \"Helvetica\";"+ "\n" + \
+"	font-size: 12px;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"/* Quick Menu "+ "\n" + \
+" */"+ "\n" + \
+""+ "\n" + \
+"QuickMenu {"+ "\n" + \
+"	background-color: #E9EFF2;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"QuickMenu QFrame#menu-frame {"+ "\n" + \
+"	border: 1px solid #9CACB4;"+ "\n" + \
+"    border-radius: 3px;"+ "\n" + \
+"    background-color: #E9EFF2;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"QuickMenu QTreeView::item {"+ "\n" + \
+"	border-bottom: 1px solid #e9eff2;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"QuickMenu QTreeView::item:selected {"+ "\n" + \
+"	background: qlineargradient("+ "\n" + \
+"		x1: 0, y1: 0, x2: 0, y2: 1,"+ "\n" + \
+"		stop: 0 #688EF6,"+ "\n" + \
+"		stop: 0.5 #4047f4,"+ "\n" + \
+"		stop: 1.0 #2D68F3"+ "\n" + \
+"	);"+ "\n" + \
+"	color: white;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"QuickMenu TabBarWidget QToolButton {"+ "\n" + \
+"	height: 25px;"+ "\n" + \
+"	border-bottom: 1px solid palette(dark);"+ "\n" + \
+"	padding-right: 5px;"+ "\n" + \
+"	padding-left: 5px;"+ "\n" + \
+"	qproperty-showMenuIndicator_: true;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"QuickMenu TabBarWidget QToolButton#search-tab-button {"+ "\n" + \
+"	background-color: #9CACB4;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"QuickMenu TabBarWidget QToolButton:menu-indicator {"+ "\n" + \
+"	image: url(canvas_icons:/arrow-right.svg);"+ "\n" + \
+"	subcontrol-position: center right;"+ "\n" + \
+"	height: 8px;"+ "\n" + \
+"	width: 8px;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"/* Quick Menu search line edit"+ "\n" + \
+" */"+ "\n" + \
+""+ "\n" + \
+"QuickMenu QLineEdit {"+ "\n" + \
+"    height: 25px;"+ "\n" + \
+"    margin: 0px;"+ "\n" + \
+"    padding: 0px;"+ "\n" + \
+"    border: 1px solid #9CACB4;"+ "\n" + \
+"    border-radius: 3px;"+ "\n" + \
+"    background-color: white;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"QuickMenu QLineEdit:focus {"+ "\n" + \
+"    border: 2px solid #9CACB4;"+ "\n" + \
+"    border-radius: 2px;"+ "\n" + \
+"}"+ "\n" + \
+""+ "\n" + \
+"QuickMenu QLineEdit QToolButton {"+ "\n" + \
+"	qproperty-flat_: false;"+ "\n" + \
+"    height: 25px;"+ "\n" + \
+"    border: 1px solid #9CACB4;"+ "\n" + \
+"    border-top-left-radius: 3px;"+ "\n" + \
+"    border-bottom-left-radius: 3px;"+ "\n" + \
+"    background-color: #9CACB4;"+ "\n" + \
+"    padding: 0px;"+ "\n" + \
+"    margin: 0px;"+ "\n" + \
+"    icon-size: 23px;"+ "\n" + \
+"}"
