@@ -50,6 +50,9 @@ from PyQt5.QtWidgets import QWidget, QDialog, QVBoxLayout, QHBoxLayout, QDialogB
 from PyQt5.QtCore import Qt
 
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
+from matplotlib.pyplot import rcParams
+
+pixels_to_inches = 1/rcParams['figure.dpi']
 
 class WavePyGenericWidget(object):
     def __init__(self, application_name=None): self._application_name = application_name
@@ -70,6 +73,7 @@ class WavePyWidget(QWidget, WavePyGenericWidget):
         WavePyGenericWidget.__init__(self, application_name=application_name)
 
         self.__allows_saving = True
+        self.__ignores_figure_dimensions = False
 
     def get_plot_tab_name(self): raise NotImplementedError()
 
@@ -78,9 +82,23 @@ class WavePyWidget(QWidget, WavePyGenericWidget):
         layout.setAlignment(Qt.AlignCenter)
 
         try: self.__allows_saving = kwargs["allows_saving"]
-        except: pass
+        except: self.__allows_saving = True
 
-        canvas = FigureCanvas(self.build_mpl_figure(**kwargs))
+        try: self.__ignores_figure_dimensions = kwargs["ignores_figure_dimensions"]
+        except: self.__ignores_figure_dimensions = False
+
+        figure = self.build_mpl_figure(**kwargs)
+
+        if not self._ignores_figure_dimensions():
+            try:    figure_width = kwargs["figure_width"]*pixels_to_inches
+            except: figure_width = figure.get_figwidth()
+            try:    figure_height = kwargs["figure_height"]*pixels_to_inches
+            except: figure_height = figure.get_figheight()
+
+            figure.set_figwidth(figure_width)
+            figure.set_figheight(figure_height)
+
+        canvas = FigureCanvas(figure)
         canvas.setParent(self)
 
         self.append_mpl_figure_to_save(canvas.figure)
@@ -106,10 +124,11 @@ class WavePyWidget(QWidget, WavePyGenericWidget):
 
     def build_mpl_figure(self, **kwargs): raise NotImplementedError()
 
-    def allows_saving(self): return self.__allows_saving
+    def _allows_saving(self): return self.__allows_saving
+    def _ignores_figure_dimensions(self): return self.__ignores_figure_dimensions
 
     def get_figures_to_save(self):
-        if self.allows_saving(): return self.__figures_to_save
+        if self._allows_saving(): return self.__figures_to_save
         else: return None
 
 
@@ -278,10 +297,11 @@ class _AbstractActivePlotter(_AbstractPlotter):
         else: return None
 
     def draw_context_on_widget(self, context_key, container_widget, add_context_label=True, unique_id=None, **kwargs):
+        context_label = context_key
         if not unique_id is None: context_key += "_" + unique_id
         container_widget.setStyleSheet(plot_tools.stylesheet_string)
 
-        main_box = plot_tools.widgetBox(container_widget, context_key if add_context_label else "", orientation="horizontal")
+        main_box = plot_tools.widgetBox(container_widget, context_label if add_context_label else "", orientation="horizontal")
         main_box.layout().setAlignment(Qt.AlignCenter)
         tab_widget = plot_tools.tabWidget(main_box)
 
@@ -298,8 +318,11 @@ class _AbstractActivePlotter(_AbstractPlotter):
                 widths.append(plot_widget_instance.width())
                 heights.append(plot_widget_instance.height())
         else:
-            label = plot_tools.widgetLabel(tab_widget, "\n\n\n\n\n        Nothing to Display")
+            tab = plot_tools.createTabPage(tab_widget, context_label)
+
+            label = plot_tools.widgetLabel(tab, "\n\n\n\n\n        Nothing to Display")
             label.setStyleSheet("font: 24pt")
+
             widths.append(500)
             heights.append(370)
 
@@ -309,9 +332,9 @@ class _AbstractActivePlotter(_AbstractPlotter):
         except: tab_widget_height = max(heights) + 35
 
         try:    main_box_width  = kwargs["main_box_width"]
-        except: main_box_width  = tab_widget_width + 5
+        except: main_box_width  = tab_widget_width + 20
         try:    main_box_height = kwargs["main_box_height"]
-        except: main_box_height = tab_widget_height + 5
+        except: main_box_height = tab_widget_height + 40
 
         try:    container_widget_width  = kwargs["container_widget_width"]
         except: container_widget_width  = tab_widget_width + 25
